// @flow

import React from 'react'
import { Action as ScrollAction } from 'react-scroll'
import cn from 'classnames'
import { injectIntl } from 'react-intl'
import { getRouteLink } from 'config'

type TReduxAction = {
  type: string,
  payload: any,
}

type TActionProps = {
  to?: string,
  href?: string,
  scrollTo?: string,
  children?: any,
  className?: string,
  action?: TReduxAction,
  dispatch?: Function,
  intl: *,
}

class Action extends React.Component<TActionProps, any> {
  RouteLink = getRouteLink()

  render() {
    // console.log('link', this.props.children)
    const {
      to,
      href,
      scrollTo,
      className: _className,
      children,
      action,
      dispatch,
      intl,
      ...props
    } = this.props
    const className = cn('link', _className)

    if (scrollTo) {
      return (
        <ScrollAction
          {...props}
          data-component="ScrollAction"
          href="#"
          className={className}
          to={scrollTo}
        >
          {children}
        </ScrollAction>
      )
    }
    if (to) {
      const { RouteLink } = this
      const _to = /^intl:/g.test(to)
        ? intl.formatMessage({ id: to.replace(/^intl:/, '') })
        : to
      return (
        <RouteLink
          {...props}
          className={className}
          data-component="RouteLink"
          to={_to}
          action={action}
        >
          {children}
        </RouteLink>
      )
    }
    if (action) {
      if (!dispatch) {
        throw new Error('Cannot use action if Component not in Redux Tree')
      }
      return (
        <a
          {...props}
          data-component="ActionAction"
          className={className}
          onClick={() => dispatch(action)}
        >
          {children}
        </a>
      )
    }

    const _href =
      href && /^intl:/g.test(href)
        ? intl.formatMessage({ id: href.replace(/^intl:/, '') })
        : href
    return (
      <a {...props} data-component="Action" className={className} href={_href}>
        {children}
      </a>
    )
  }
}

export default injectIntl(Action)
