// @flow

import React from 'react'
import { compose } from 'recompose'
import cn from 'classnames'
import createConnectRedux from 'helpers/createConnectRedux'
import withFormStore from 'helpers/withFormStore'
import {
  sendRequest,
  updateUrl,
  setLocalStorage,
  getBehavior,
  getStories,
  mergeStories,
} from './utils'

const listAction = {
  sendRequest,
  updateUrl,
  setLocalStorage,
}

/**
 * actions by button as setLocalStorage, updateUrl, sendRequest (xhr)
 * button sources props: [{ source: string ('redux' | 'local'), form: string }]
 * maybe updateUrl or sendRequest with multi data form get by getStories, merged by mergeStories
 * when setLocalStorage, need props name, should use form name
 */

function Button({
  className,
  name,
  type,
  sources,
  options,
  behavior,
  formStore,
  children,
  tag: Component = 'div',
  theme = {},
  ...props
}: TButton) {
  const handle = listAction[type]
  const stories = getStories({ sources, formStore })
  const { success: whenSuccess, error: whenError } =
    getBehavior(behavior || {}) || {}
  return (
    <Component
      {...props}
      data-component="Button"
      className={cn(theme.root, className)}
      type={type}
      onClick={() =>
        handle &&
        handle({
          ...options,
          values: mergeStories(stories) || {},
          name,
          whenSuccess,
          whenError,
        })}
    >
      {children}
    </Component>
  )
}

export default compose(createConnectRedux, withFormStore)(Button)
