// @flow

// import dotProp from 'dot-prop-immutable'
import axios from 'axios'
import merge from 'lodash.merge'

const prefixKey = 'form'

type TNotify = {
  whenSuccess: Function,
  whenError: Function,
}

export const sendRequest = ({
  values,
  method = 'post',
  endpoint,
  hiddenValues,
  urlValues,
  whenSuccess,
  whenError,
}: {
  values: { [key: string]: any },
  method: 'post' | 'get',
  endpoint: String,
  hiddenValues?: { [key: string]: any },
  urlValues?: { [key: string]: any },
} & TNotify) => {
  axios({
    method,
    url: endpoint,
    data: { ...values, ...hiddenValues, ...urlValues },
    headers: { 'X-Requested-With': 'XMLHttpRequest' },
    responseType: 'json',
  })
    .then((response) => {
      if (response && response.status === 200 && response.data) {
        whenSuccess()
      } else {
        whenError()
      }
    })
    .catch(() => {
      whenError()
    })
}

export const updateUrl = ({
  values,
  hiddenValues,
}: {
  values: { [key: string]: any },
  hiddenValues?: { [key: string]: any },
} & TNotify) => {
  // TODO: handle update url
  console.log(
    {
      values,
      hiddenValues,
    },
    'updateUrl',
  )
}

export const isJson = (d: string) => {
  try {
    const j = JSON.parse(d)
    return true
  } catch (err) {
    return false
  }
}

export const getLocalStorage = (n: string) => {
  if (!window) return false
  // return dotProp(window.localStorage, `${prefixKey}.${n}`)
  const d = window.localStorage[`${prefixKey}.${n}`]
  return (isJson(d) && JSON.parse(d)) || {}
}

export const removeLocalStorage = (n: string) => {
  if (!window) return false
  window.localStorage[`${prefixKey}.${n}`] = undefined
  // window.localStorage = dotProp.delete(window.localStorage, `${prefixKey}.${n}`)
  return true
}

export const setLocalStorage = ({
  name,
  values,
  hiddenValues,
  whenSuccess,
  whenError,
}: {
  name: string,
  values: { [key: string]: any },
  hiddenValues?: { [key: string]: any },
} & TNotify) => {
  if (!window) return whenError()
  window.localStorage[`${prefixKey}.${name}`] = JSON.stringify({
    ...values,
    ...hiddenValues,
  })
  return whenSuccess()
}

export const getBehavior = ({
  onSuccess,
  messageOnSuccess,
  directOnSuccess,
  onError,
  messageOnError,
  directOnError,
  directHandler,
}: {
  onSuccess?: Function,
  messageOnSuccess?: any,
  directOnSuccess?: string,
  onError?: Function,
  messageOnError?: any,
  directOnError?: string,
  directHandler?: Function,
}) => {
  // TODO: will update here
  const success = () => {
    if (onSuccess) onSuccess()
    if (messageOnSuccess) alert(messageOnSuccess)
    if (directOnSuccess) {
      return (
        (directHandler && directHandler(directOnSuccess)) ||
        window.location.replace(directOnSuccess)
      )
    }
    return true
  }
  const error = () => {
    if (onError) onError()
    if (messageOnError) alert(messageOnError)
    if (directOnError) {
      return (
        (directHandler && directHandler(directOnError)) ||
        window.location.replace(directOnError)
      )
    }
    return true
  }

  return { success, error }
}

export const getStories = ({
  sources,
  formStore,
}: {
  sources: any,
  formStore: any,
}) =>
  sources.map(
    ({ source: s, form: f } = {}) =>
      (s === 'local' ? getLocalStorage(f) : formStore[f]),
  )

export const mergeStories = (stories: any) => {
  const object = {}
  stories.map(s => merge(object, s))
  return object
}
