// @flow

import React from 'react'
import ProgressiveImage from 'react-progressive-image'
import getImageLink from 'helpers/getImageLink'

type TImageProps = {
  image: TImageData,
  alt?: string,
  title?: string,
  size: TSize,
  className?: string,
}

export function Image({
  image,
  alt,
  title,
  className,
  size,
  ...props
}: TImageProps) {
  const source = getImageLink({ ...image, boxSize: size })
  if (typeof source === 'string') {
    return (
      <img
        {...props}
        src={source}
        className={className}
        alt={alt}
        title={title}
      />
    )
  }
  const { thumbnail, large } = source
  return (
    <ProgressiveImage src={large} placeholder={thumbnail}>
      {imageSource => (
        <img
          {...props}
          className={className}
          src={imageSource}
          alt={alt}
          title={title}
        />
      )}
    </ProgressiveImage>
  )
}

export default Image
