// @flow

import React from 'react'
import ProgressiveImage from 'react-progressive-image'
import getImageLink from 'helpers/getImageLink'

type TWrapper = {
  className?: string,
  size: TSize,
  overlayColor?: string,
  image?: TImageData,
  tag?: string,
  alt?: string,
  children: any,
}

function getBackground(overlayColor: string, imageSource?: string) {
  if (!imageSource) {
    return `linear-gradient(${overlayColor}, ${overlayColor})`
  }
  return `linear-gradient(${overlayColor}, ${overlayColor}), url(${imageSource})`
}

function Wrapper({
  className,
  size,
  image,
  overlayColor = 'rgba(0, 0, 0, 0)',
  tag: Component = 'div',
  alt,
  children,
  ...props
}: TWrapper) {
  const source = getImageLink({
    ...image,
    boxSize: size,
    usePlaceholder: false,
  })
  if (typeof source === 'string') {
    const backgroundImage = getBackground(overlayColor, source)
    return (
      <Component
        {...props}
        className={className}
        style={{ backgroundImage }}
      >
        {alt && <img src={source} alt={alt} style={{ display: 'none' }} />}
        {children}
      </Component>
    )
  }

  const { thumbnail, large } = source

  return (
    <ProgressiveImage src={large} placeholder={thumbnail}>
      {(imageSource) => {
        const backgroundImage = getBackground(overlayColor, imageSource)
        return (
          <Component
            {...props}
            className={className}
            style={{ backgroundImage }}
          >
            {alt && <img src={large} alt={alt} style={{ display: 'none' }} />}
            {children}
          </Component>
        )
      }}
    </ProgressiveImage>
  )
}

export default Wrapper
