// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { Field } from 'redux-form'
import InputWrapper from './InputWrapper'

type InputProps = {
  name: string,
  type: string,
  icon: string,
  label?: string,
  theme: { [key: string]: string },
}

class Input extends React.PureComponent<InputProps, *> {
  component = ({ input: inputProps, meta }: *) => {
    const { type, icon, label, theme, ...props } = this.props
    return (
      <InputWrapper
        {...props}
        icon={icon}
        label={label}
        meta={meta}
        theme={theme}
      >
        <input type={type} className={theme.input} {...inputProps} />
      </InputWrapper>
    )
  }

  render() {
    const { name } = this.props
    return (
      <Field
        name={name}
        component={this.component}
      />
    )
  }
}

export default themr('Input', {}, { composeTheme: 'softly' })(Input)
