// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Icon from 'components/Icon'

type InputWrapperProps = {
  name: string,
  meta: *,
  meta: *,
  icon?: string,
  label?: string,
  theme: { [key: string]: string },
}

class InputWrapper extends React.PureComponent<any, InputWrapperProps> {
  ref: Function
  input: any

  static defaultProps = {
    className: undefined,
    label: undefined,
  }

  ref = (ref) => {
    this.input = ref
  }

  render() {
    const {
      icon,
      label,
      meta,
      children,
      theme,
      ...rest
    } = this.props
    return (
      <div
        {...rest}
        className={cn(theme.root)}
        onClick={() => this.input.focus()}
      >
        {!!label && (
          <div className={theme.labelWrapper}>
            <label className={theme.label}>
              {label}
            </label>
          </div>
        )}
        <div className={theme.valueWrapper}>
          {!!icon && <Icon key="icon" className={theme.icon} icon={icon} />}
          {React.cloneElement(children, { ref: this.ref })}
          {meta.error && <div className={theme.error}>{meta.error}</div>}
        </div>
      </div>
    )
  }
}

export default themr('InputWrapper', {}, { composeTheme: 'softly' })(InputWrapper)
