// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Icon from 'components/Icon'

type RadioProps = {
  field: string,
  type: string,
  multiline: boolean,
  icon: string,
  label?: string,
  error?: string,
  className?: string,
  theme: { [key: string]: string },
  options: Array<{ value: string, label: string }>,
}

class Radio extends React.PureComponent<RadioProps, any> {
  ref: any

  static defaultProps = {
    className: undefined,
    label: undefined,
  }

  render() {
    const {
      field,
      options = [],
      icon,
      label,
      error,
      className,
      theme,
      ...rest
    } = this.props
    return (
      <div
        className={cn(theme.root, className)}
        // onClick={() => this.ref.focus()}
      >
        {!!label && (
          <div className={theme.labelWrapper}>
            <label className={theme.label} htmlFor={field}>
              {label}
            </label>
          </div>
        )}
        <div className={theme.valueWrapper}>
          {!!icon && <Icon key="icon" className={theme.icon} icon={icon} />}
          {options.map(item => (
            <div key={item.value} className={theme.row}>
              <input
                {...rest}
                type="radio"
                className={theme.input}
                name={field}
                value={item.value}
              />
              <span className={theme.inputLabel}>{item.label}</span>
            </div>
          ))}
          {error && <div className={theme.error}>{error}</div>}
        </div>
      </div>
    )
  }
}

export default themr('Radio', {}, { composeTheme: 'softly' })(Radio)
