// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { Field } from 'redux-form'
import InputWrapper from './InputWrapper'

type SelectProps = {
  name: string,
  icon: string,
  label?: string,
  options: Array<{ value: string, label: string }>,
  theme: { [key: string]: string },
}

class Select extends React.Component<SelectProps, *> {
  component = ({ input: inputProps, meta }: *) => {
    const { icon, label, options, theme } = this.props
    return (
      <InputWrapper icon={icon} label={label} meta={meta} theme={theme}>
        <select
          {...inputProps}
          className={theme.input}
        >
          {options.map(item => (
            <option key={item.value} value={item.value}>
              {item.label}
            </option>
          ))}
        </select>
      </InputWrapper>
    )
  }

  render() {
    const { name } = this.props
    return <Field name={name} component={this.component} />
  }
}

export default themr('Select', {}, { composeTheme: 'softly' })(Select)
