// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Wrapper from 'components/Wrapper'

function Hero({
  className,
  tag: Component = 'div',
  overlayColor = 'rgba(0, 0, 0, 0)',
  image,
  poster,
  videos,
  theme,
  children,
  ...rest
}: {
  className: string,
  tag: string,
  overlayColor?: string,
  image: TImageData,
  poster: string,
  videos: {
  src: string,
  type: string,
  }[],
  children: any,
  theme: TTheme,
  }) {
  return (
    <Component
      {...rest}
      data-component="Hero"
      // Use flex justify-center to make children always center
      // Use overflow-x-hidden to prevent video overflow x
      className={cn('relative overflow-hidden flex justify-center', className, theme.root)}
    >
      {image && (
        <Wrapper
          className="absolute absolute--fill z-0"
          image={image}
          theme={theme.background}
        />
      )}
      {overlayColor && (
        <Wrapper
          className="absolute absolute--fill z-1"
          overlayColor={overlayColor}
          theme={theme.background}
        />
      )}
      {videos && (
        <video
          className={cn('z-0 absolute', theme.video)}
          playsInline
          autoPlay
          muted
          loop
          poster={poster}
        >
          {videos.map(video => (
            <source
              key={video.src}
              src={video.src}
              type={video.type || 'video/mp4'}
            />
          ))}
        </video>
      )}
      <div className={cn('absolute absolute--fill z-0 z-2', theme.container)}>{children}</div>
    </Component>
  )
}

export default themr('Hero', {}, { composeTheme: 'softly' })(Hero)
