// @flow

import React from 'react'
import cn from 'classnames'
import { storiesOf } from '@storybook/react'
import Hero from './index'

const theme = {
  root: 'w-100 aspect-ratio--1x1 aspect-ratio--4x3-m aspect-ratio--16x9-l',
  background: {
    root: 'cover',
  },
  container: 'flex items-center justify-center',
}

const withImageSrcProps = {
  tag: 'div',
  image: {
    src: 'https://source.unsplash.com/user/erondu/1600x900',
  },
  theme,
}

const withCloudinaryImageProps = {
  tag: 'div',
  image: {
    cloudinary: {
      username: 'alice28',
      id: 'sanh-don.jpg',
    },
  },
  theme,
}

const videos = [
  {
    src:
      'http://res.cloudinary.com/doci3layd/video/upload/v1511512766/Movenpick_Resort_Ph%C3%BA_Qu%E1%BB%91c_-_0909939186_1_i70qio.mp4',
  },
]
const withFullWidthVideosProps = {
  tag: 'div',
  videos,
  theme: {
    ...theme,
    root: 'w-100 bg-light-gray h4',
    video: 'w-100',
  },
}
const withFullHeightVideosProps = {
  tag: 'div',
  videos,
  theme: {
    ...theme,
    root: 'w5 h5 bg-light-gray center',
    video: 'h-100',
  },
}

const wrapperClassName = 'mw5 mw6-m mw7-l center'
const childComponent = <div className="white f3">Awesome Title goes here</div>

storiesOf('Hero', module)
  .add('with image use src', () => (
    <div className={wrapperClassName}>
      <Hero {...withImageSrcProps}>{childComponent}</Hero>
    </div>
  ))
  .add('with image use cloudinary', () => (
    <div className={wrapperClassName}>
      <Hero {...withCloudinaryImageProps}>{childComponent}</Hero>
    </div>
  ))
  .add('with image use cloudinary & overlay', () => (
    <div className={wrapperClassName}>
      <Hero {...withCloudinaryImageProps} overlayColor="rgba(0, 0, 0, 0.35)">
        {childComponent}
      </Hero>
    </div>
  ))
  .add('with image use src & overlay', () => (
    <div className={wrapperClassName}>
      <Hero {...withImageSrcProps} overlayColor="rgba(0, 0, 0, 0.35)">
        {childComponent}
      </Hero>
    </div>
  ))
  .add('with video full height', () => (
    <div className={cn(wrapperClassName)}>
      <Hero {...withFullHeightVideosProps}>
        {childComponent}
      </Hero>
    </div>
  ))
  .add('with video full width & overlay', () => (
    <div className={wrapperClassName}>
      <Hero {...withFullWidthVideosProps} overlayColor="rgba(0, 0, 0, 0.75)">
        {childComponent}
      </Hero>
    </div>
  ))
