// @flow

import React from 'react'
import Text from 'components/Text'
import Icon from 'components/Icon'
import getTextTheme from 'helpers/getTextTheme'

function IconItem({
  icon,
  title,
  subtitle,
  description,
  theme = {},
}: TIconItem) {
  return (
    <div data-component="IconItem" className={theme.root}>
      <div className={theme.iconWrapper}>
        <Icon icon={icon} className={theme.icon} />
      </div>
      <div className={theme.contentWrapper}>
        {title && (
          <Text field="title" theme={getTextTheme({ theme, field: 'title' })}>
            {title}
          </Text>
        )}
        {subtitle && (
          <Text
            field="subtitle"
            theme={getTextTheme({ theme, field: 'subtitle' })}
          >
            {subtitle}
          </Text>
        )}
        {description && (
          <Text
            field="description"
            theme={getTextTheme({ theme, field: 'description' })}
          >
            {description}
          </Text>
        )}
      </div>
    </div>
  )
}

export default IconItem
