// @flow

import React from 'react'
import { mount } from 'enzyme'
import { Image } from '../index'

describe('Image', () => {
  it('use src', () => {
    const src = 'https://source.unsplash.com/random/800x600'
    const wrapper = mount(
      <Image className="bg" image={{ src }} alt="code" theme={{}} />,
    )
    const imgComponent = wrapper.find('img')
    expect(imgComponent.props().src).toEqual(src)
  })

  it('use src cloudinary', () => {
    const src =
      'https://res.cloudinary.com/lh-imagecloud/image/upload/v1501418680/css-code_t7qmyu.jpg'
    const result =
      'https://res.cloudinary.com/lh-imagecloud/image/upload/c_scale,q_auto,w_50/css-code_t7qmyu.jpg'
    const wrapper = mount(
      <Image className="bg" image={{ src }} alt="code" theme={{}} />,
    )
    const imgComponent = wrapper.find('img')
    expect(imgComponent.props().src).toEqual(result)
  })

  it('use cloudinary image', () => {
    const result =
      'https://res.cloudinary.com/lh-imagecloud/image/upload/c_scale,q_auto,w_50/css-code_t7qmyu.jpg'
    const cloudinary = {
      username: 'lh-imagecloud',
      id: 'css-code_t7qmyu.jpg',
    }
    const wrapper = mount(
      <Image
        className="bg"
        image={{ cloudinary }}
        alt="code"
        size={{
          width: 250,
          height: 250,
        }}
        theme={{}}
      />,
    )
    const imgComponent = wrapper.find('img')
    expect(imgComponent.props().src).toEqual(result)
  })

  it('use cloudinary image (SSR)', () => {
    const result =
      'https://res.cloudinary.com/lh-imagecloud/image/upload/c_scale,q_auto,w_50/css-code_t7qmyu.jpg'
    const cloudinary = {
      username: 'lh-imagecloud',
      id: 'css-code_t7qmyu.jpg',
    }
    const wrapper = mount(
      <Image
        className="bg"
        image={{ cloudinary }}
        alt="code"
        size={{}} // SSR mean size width, height & position = null
        theme={{}}
      />,
    )
    const imgComponent = wrapper.find('img')
    expect(imgComponent.props().src).toEqual(result)
  })
})
