// @flow

import React from 'react'
import cn from 'classnames'
import sizeMe from 'react-sizeme'
import ProgressiveImage from 'react-progressive-image'
import getImageLink from 'helpers/getImageLink'

type TImageProps = {
  image: TImageData,
  alt: string,
  size?: TSize,
  autoScale?: boolean,
  steps?: number[],
  className?: string,
  theme: TTheme,
}

export function Image({
  image,
  alt,
  className,
  size,
  autoScale,
  steps,
  theme = {},
  ...props
}: TImageProps) {
  const source = getImageLink({ ...image, boxSize: size, autoScale })
  if (typeof source === 'string') {
    return (
      <img
        {...props}
        src={source}
        className={cn(className, theme.root)}
        alt={alt}
      />
    )
  }
  const { thumbnail, large } = source
  return (
    <ProgressiveImage src={large} placeholder={thumbnail}>
      {imageSource => (
        <img
          {...props}
          className={cn(className, theme.root)}
          src={imageSource}
          alt={alt}
        />
      )}
    </ProgressiveImage>
  )
}

export default sizeMe({
  refreshMode: 'debounce',
  refreshRate: 16,
  monitorHeight: true,
  monitorWidth: true,
  enableSSRBehaviour: true,
})(Image)
