// @flow

import React from 'react'
import Text from 'components/Text'
import IconItemList from 'components/IconItemList'
import KeyValueList from 'components/KeyValueList'
import Actions from 'components/Actions'
import getTextTheme from 'helpers/getTextTheme'

function InfoItem({
  title,
  subtitle,
  description,
  iconItems,
  keyValueItems,
  actions,
  theme = {},
}: TInfoItem) {
  return (
    <div data-component="InfoItem" className={theme.root}>
      <div className={theme.contentWrapper}>
        {title && (
          <Text field="title" theme={getTextTheme({ theme, field: 'title' })}>
            {title}
          </Text>
        )}
        {subtitle && (
          <Text
            field="subtitle"
            theme={getTextTheme({ theme, field: 'subtitle' })}
          >
            {subtitle}
          </Text>
        )}
        {description && (
          <Text
            field="description"
            theme={getTextTheme({ theme, field: 'description' })}
          >
            {description}
          </Text>
        )}
      </div>
      {iconItems &&
        iconItems.length > 0 && (
          <IconItemList items={iconItems} theme={theme.iconItemList} />
        )}
      {keyValueItems &&
        keyValueItems.length > 0 && (
          <KeyValueList items={keyValueItems} theme={theme.keyValueList} />
        )}
      {actions &&
        actions.length > 0 && <Actions items={actions} theme={theme.actions} />}
    </div>
  )
}

export default InfoItem
