// @flow

import React from 'react'
import { mount } from 'enzyme'
import Link from '../index'

describe('Link', () => {
  it('use href', () => {
    const wrapper = mount(<Link href="https://www.google.com">Click me!</Link>)
    expect(wrapper.find('a').props().href).toEqual('https://www.google.com')
  })
  it('use scrollto', () => {
    const wrapper = mount(<Link scrollTo="element">Click me!</Link>)
    expect(wrapper.find('a').props()['data-component']).toEqual('ScrollLink')
    expect(typeof wrapper.find('a').props().onClick).toEqual('function')
  })

  describe('Redux Action', () => {
    const action = { type: 'open_modal', payload: { modalId: 'optIn01' } }
    const dispatch = jest.fn()

    it('use redux action without dispatch -> throw error', () => {
      try {
        mount(<Link action={action}>Click me!</Link>)
        throw new Error('Throw error if code goes here')
      } catch (err) {
        expect(err.message).toEqual('Cannot use action if Component not in Redux Tree')
      }
    })

    const wrapper = mount(
      <Link
        dispatch={dispatch}
        action={action}
      >
        Click me!
      </Link>,
    )

    it('use redux action with dispatch', () => {
      expect(wrapper.find('a').props()['data-component']).toEqual('ActionLink')
    })

    it('click ActionLink will call dispatch', () => {
      wrapper.find('a').simulate('click')
      expect(dispatch).toHaveBeenLastCalledWith(action)
    })
  })
})
