// @flow

import React from 'react'
import Uppy from 'uppy/lib/core'
import Tus from 'uppy/lib/plugins/Tus'
import { DashboardModal } from 'uppy/lib/react'
import Icon from 'components/Icon'
import { themr } from 'react-css-themr'
import cn from 'classnames'

type FileUploadProps = {
  endpoint: string,
  onChange: Function,
  children: *,
  buttonTag: *,
  openIcon: string,
  openText: string,
  closeIcon: string,
  closeText: string,
  className?: string,
  theme: *,
}

class UploadModal extends React.Component<FileUploadProps, *> {
  static defaultProps = {
    buttonTag: 'a',
    openText: 'Open',
    closeText: 'Close',
  }

  uppy: *

  state = {
    modalOpen: false,
    files: [],
  }

  componentWillMount() {
    const { endpoint, onChange } = this.props
    this.uppy = new Uppy({ autoProceed: false }).use(Tus, { endpoint }).run()
    this.uppy.on('complete', (result) => {
      const files = [...this.state.files, ...result.successful]
      this.setState(
        {
          files,
        },
        () => onChange(this.state.files),
      )
    })
  }

  componentWillUnmount() {
    this.uppy.close()
  }

  handleOpen = () => {
    this.setState({
      modalOpen: true,
    })
  }

  handleClose = () => {
    this.setState({
      modalOpen: false,
    })
  }

  render() {
    const {
      children,
      buttonTag: Button,
      openText,
      closeText,
      openIcon,
      closeIcon,
      theme,
      className,
      ...rest
    } = this.props
    return (
      <div className={cn(className, theme.root)} {...rest}>
        <Button className={theme.button} onClick={this.handleOpen}>
          {this.state.modalOpen ? (
            closeIcon && <Icon className={theme.buttonIcon} icon={closeIcon} />
          ) : (
            openIcon && <Icon className={theme.buttonIcon} icon={openIcon} />
          )}
          <span className={theme.buttonText}>{this.state.modalOpen ? closeText : openText}</span>
        </Button>
        <DashboardModal
          uppy={this.uppy}
          closeModalOnClickOutside
          open={this.state.modalOpen}
          onRequestClose={this.handleClose}
        />
      </div>
    )
  }
}

export default themr('UploadModal', {}, { composeTheme: 'softly' })(UploadModal)
