// @flow

import React from 'react'
import cn from 'classnames'

type TVideoProps = {
  className?: string,
  sources: any[],
  tracks?: any[],
  theme?: TTheme,
}

export function Video({
  className,
  sources = [],
  tracks = [],
  theme = {},
  ...rest
}: TVideoProps) {
  return (
    <video // eslint-disable-line
      controls
      {...rest}
      data-component="Video"
      className={cn(className, theme.root)}
    >
      {(sources || []).map(({ ...source }, idx) => (
        <source key={idx} {...source} /> // eslint-disable-line
      ))}
      {(tracks || []).map(({ ...track }, idx) => (
        <track key={idx} {...track} /> // eslint-disable-line
      ))}
    </video>
  )
}

export default Video
